@@ -11,3 +11,7 @@ pub use implements_sync::implements_sync;
 
 mod implements_clone;
 pub use implements_clone::implements_clone;
+
+mod implements_debug;
+pub use implements_debug::implements_debug;
+
