@@ -165,6 +165,12 @@ impl LogFormatter {
     ) -> Self {
         let ident = ident.as_ref().to_string();
 
+        // TODO: test this
+        assert!(
+            ident.len() < total_width,
+            "Identation length must be smaller than total width.",
+        );
+
         return LogFormatter {
             total_width,
             ident,
@@ -191,7 +197,14 @@ impl LogFormatter {
         value: T,
     ) -> String {
         let value_str = label.as_ref();
-        let width = self.total_width - self.ident.len() - value_str.len();
+        let width_substract = self.ident.len() - value_str.len();
+
+        // TODO: test this
+        let width = if self.total_width >= width_substract {
+            self.total_width - width_substract
+        } else {
+            self.total_width
+        };
 
         return format!(
             "{ident}{value}{:.>width$}\n",
@@ -219,7 +232,14 @@ impl LogFormatter {
         &self,
         label: S,
     ) -> String {
-        let width = self.total_width - self.ident.len() - label.as_ref().len();
+        let width_substract = self.ident.len() - label.as_ref().len();
+
+        // TODO: test this
+        let width = if self.total_width >= width_substract {
+            self.total_width - width_substract
+        } else {
+            self.total_width
+        };
     
         return format!(
             "{ident}{caption}{:>width$}\n",
@@ -233,7 +253,14 @@ impl LogFormatter {
         &self,
         label: S,
     ) -> String {
-        let width = self.total_width - self.ident.len();
+        let width_substract = self.ident.len();
+
+        // TODO: test this
+        let width = if self.total_width >= width_substract {
+            self.total_width - width_substract
+        } else {
+            self.total_width
+        };
     
         return format!(
             "{ident}{:>width$}\n",
